<h1>
    <b>kernpy documentation</b>
</h1>
<b>Date:</b> <script>document.write(new Date().toLocaleDateString("en-US", {year: 'numeric', month: 'short', day: '2-digit'}));</script> &nbsp;

<b>Download documentation:</b> [Zipped HTML](https://github.com/OMR-PRAIG-UA-ES/kernpy/archive/refs/heads/gh-pages.zip)

## Useful links:
[Installation](get-started.md) &nbsp;|&nbsp; [Source Repository](https://github.com/OMR-PRAIG-UA-ES/kernpy){:target="_blank"} &nbsp;|&nbsp; [Project Website (PRAIG)](https://praig.ua.es/){:target="_blank"}

`kernpy` is a python package that provides utilities for working with **kern and **mens data.

## Contents

<main class="grid-container">
    <div class="grid-item">
        <img src="assets/running.svg" alt="Getting Started Icon" class="grid-icon">
        <h2><b>Getting started</b></h2>
        <p>New to <code>kernpy</code>? Check out the getting started guides. They contain an introduction to <code>kernpy</code>'s main concepts and links to additional tutorials.</p>
        <a href="get-started" class="btn">To the getting started guides</a>
    </div>
    <div class="grid-item">
        <img src="assets/learn.svg" alt="How-To Guide Icon" class="grid-icon">
        <h2><b>How-To guide</b></h2>
        <p>The How-To guides provide in-depth information on how to perform specific tasks with <code>kernpy</code> step-by-step.</p>
        <a href="how-to-guides" class="btn">To the How-To guides</a>
    </div>
    <div class="grid-item">
        <img src="assets/book.svg" alt="API Reference Icon" class="grid-icon">
        <h2><b>API reference</b></h2>
        <p>The API reference contains a detailed description of the <code>kernpy</code> API. It describes how the methods work and which parameters can be used.</p>
        <a href="reference" class="btn">To the API reference</a>
    </div>
    <div class="grid-item">
        <img src="assets/meeting.svg" alt="About Icon" class="grid-icon">
        <h2><b>About</b></h2>
        <p>Find out more about the <code>kernpy</code> project, including the team, how to contribute, and the license.</p>
        <a href="about" class="btn">To the About page</a>
    </div>
</main>

<section class="grid-container align-right">
    <div>
        <p>Next</p>
        <p><a href="get-started" class="btn link-underline-dark text-lg-start" >Getting Started</a></p>
    </div>   

    <div>
        <p>Previous</p>
        <p><a href="get-started" class="btn text-lg-start" >Getting Started</a></p>
    </div>   


</section>

<br>

Quickly find what you are looking for depending on
your use case by looking at the different pages.

## Acknowledgements
University of Alicante.
